package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.SecurityGroupServices;

/**
 * 安全组服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface ISecurityGroupServicesService 
{
    /**
     * 查询安全组服务
     * 
     * @param id 安全组服务主键
     * @return 安全组服务
     */
    public SecurityGroupServices selectSecurityGroupServicesById(Integer id);

    /**
     * 查询安全组服务列表
     * 
     * @param securityGroupServices 安全组服务
     * @return 安全组服务集合
     */
    public List<SecurityGroupServices> selectSecurityGroupServicesList(SecurityGroupServices securityGroupServices);

    /**
     * 新增安全组服务
     * 
     * @param securityGroupServices 安全组服务
     * @return 结果
     */
    public int insertSecurityGroupServices(SecurityGroupServices securityGroupServices);

    /**
     * 修改安全组服务
     * 
     * @param securityGroupServices 安全组服务
     * @return 结果
     */
    public int updateSecurityGroupServices(SecurityGroupServices securityGroupServices);

    /**
     * 批量删除安全组服务
     * 
     * @param ids 需要删除的安全组服务主键集合
     * @return 结果
     */
    public int deleteSecurityGroupServicesByIds(Integer[] ids);

    /**
     * 删除安全组服务信息
     * 
     * @param id 安全组服务主键
     * @return 结果
     */
    public int deleteSecurityGroupServicesById(Integer id);
}
