package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.SecurityGroupServices;
import com.zyc.system.service.ISecurityGroupServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 安全组服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/SecurityGroupServicesController")
public class SecurityGroupServicesController extends BaseController
{
    @Autowired
    private ISecurityGroupServicesService securityGroupServicesService;

    /**
     * 查询安全组服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(SecurityGroupServices securityGroupServices)
    {
        startPage();
        List<SecurityGroupServices> list = securityGroupServicesService.selectSecurityGroupServicesList(securityGroupServices);
        return getDataTable(list);
    }

    /**
     * 导出安全组服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "安全组服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SecurityGroupServices securityGroupServices)
    {
        List<SecurityGroupServices> list = securityGroupServicesService.selectSecurityGroupServicesList(securityGroupServices);
        ExcelUtil<SecurityGroupServices> util = new ExcelUtil<SecurityGroupServices>(SecurityGroupServices.class);
        util.exportExcel(response, list, "安全组服务数据");
    }

    /**
     * 获取安全组服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(securityGroupServicesService.selectSecurityGroupServicesById(id));
    }

    /**
     * 新增安全组服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "安全组服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SecurityGroupServices securityGroupServices)
    {
        return toAjax(securityGroupServicesService.insertSecurityGroupServices(securityGroupServices));
    }

    /**
     * 修改安全组服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "安全组服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SecurityGroupServices securityGroupServices)
    {
        return toAjax(securityGroupServicesService.updateSecurityGroupServices(securityGroupServices));
    }

    /**
     * 删除安全组服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "安全组服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(securityGroupServicesService.deleteSecurityGroupServicesByIds(ids));
    }
}
